@@ -15,8 +15,8 @@ except ImportError:
     from Queue import Queue
 
 
-from .variables import task_pidfile
-from .public import write_pid
+from mjworker.variables import task_pidfile
+from mjworker.public import write_pid
 
 def post_task_status(hisId, jobState, jobResult, master_data):
     data = {"sessionId": master_data['sessionId'], "timestamp": str(round(time.time()*1000000)),
@@ -70,17 +70,20 @@ def task_timeout(func):
 
 
 # @task_timeout
-def task_consumer(task, master_data):
-    try:
-        task_dic = json.loads(task)
-        his_id = task_dic["content"]["his_id"]
-        job_content = task_dic["content"]["job_content"]
-        r = subprocess.run(job_content, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-        print("comand output: ", r.stdout)
-        post_task_status(his_id, r.returncode, str(r.stdout), master_data)
-    except Exception as e:
-        print("task_consumer error", e)
-        
+def task_consumer(queue, master_data):
+    while True:
+        try:
+            task = queue.get()
+            print("---出队列: {}".format(task))
+            task_dic = json.loads(task)
+            his_id = task_dic["content"]["his_id"]
+            job_content = task_dic["content"]["job_content"]
+            r = subprocess.run(job_content, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+            # print("comand output: ", r.stdout)
+            post_task_status(his_id, r.returncode, str(r.stdout), master_data)
+        except Exception as e:
+            print("task_consumer error", e)
+
 
 def task_producer(queue, master_data):
     while True:
@@ -91,6 +94,7 @@ def task_producer(queue, master_data):
         print("---入队列: {}".format(task))
         queue.put(task)
 
+
 def task_runner(master_data):
     print("---------------")
     print("task_runner:", master_data)
@@ -98,11 +102,11 @@ def task_runner(master_data):
     write_pid(current_process().pid, task_pidfile)
     queue = Queue(maxsize=50)
     producer = Thread(target=task_producer, args=(queue, master_data))
+    consumer = Thread(target=task_consumer, args=(queue, master_data))
     producer.start()
-    while True:
-        task = queue.get()
-        print("---出队列: {}".format(task))
-        task_consumer(task, master_data)
+    consumer.start()
+    producer.join()
+    consumer.join()
 
 if __name__ == '__main__':
     master_data = {'server': 'http://172.17.36.204:8000', 'workerId': '7344df70-c1cd-55e7-899c-16de62b79607', 'sessionId': 'bccb4f8c-b2c9-11eb-adba-005056b9fd37', 'timeout': 10}
